package intient.xml.exception;

/**
 * Exception thrown when a signature block reference validation exception has occurred.
 * 
 * @author Bradley Beddoes
 */
public class ReferenceValueException extends Exception {
	private static final long serialVersionUID = 2322773577278774501L;
	private Object jaxbObject;

	/**
	 * Exception thrown when a signature block reference validation exception has occurred.
	 * 
	 * @param message
	 *            Human readable message indicating why this exception was thrown
	 * @param cause
	 *            Any exception which caused this exception to be thrown, may be null
	 */
	public ReferenceValueException(String message, Exception cause, Object jaxbObject) {
		super(message, cause);
		this.jaxbObject = jaxbObject;
	}

	/**
	 * Note that since signature validation has failed at this stage, the object returned here should not be trusted for
	 * anything other than generating log output.
	 * 
	 * @return The JAXB Object containing the document that failed signature validation.
	 */
	public Object getJAXBObject() {
		return this.jaxbObject;
	}
}
