package intient.xml.exception;

/**
 * Exception thrown when an underlying library has caused an exception to occur or some generic localized error state
 * has occurred. Will populate semi converted JAXB Object when possible, this should not be relied on for anything other
 * then error state logging.
 * 
 * @author Bradley Beddoes
 */
public class UnmarshallerException extends Exception {
	private static final long serialVersionUID = 7979183950128985565L;
	private Object jaxbObject;

	/**
	 * Exception thrown when an underlying library has caused an exception to occur or some generic localized error
	 * state has occurred.
	 * 
	 * @param message
	 *            Human readable message indicating why this exception was thrown
	 * @param cause
	 *            Any exception which caused this exception to be thrown, may be null
	 */
	public UnmarshallerException(String message, Exception cause) {
		super(message, cause);
	}

	/**
	 * Exception thrown when an underlying library has caused an exception to occur or some generic localized error
	 * state has occurred.
	 * 
	 * @param message
	 *            Human readable message indicating why this exception was thrown
	 * @param cause
	 *            Any exception which caused this exception to be thrown, may be null
	 */
	public UnmarshallerException(String message, Exception cause, Object jaxbObject) {
		super(message, cause);
		this.jaxbObject = jaxbObject;
	}

	/**
	 * @return The semi populated JAXB Object when available
	 */
	public Object getJAXBObject() {
		return this.jaxbObject;
	}

}
