package intient.xml.keys;

import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.cert.Certificate;

/**
 * Interface to allow resolution of key pairs from various (generally Keystore) sources.
 * 
 * @author Bradley Beddoes
 */
public interface KeyPairSelector
{
	/**
	 * @return The private key associated with the local entity, or null if
	 * 		this resolver is not associated with a local key.
	 */
	public PrivateKey getPrivateKey();
	
	/**
	 * @return The public key associated with the local entity, or null if
	 * 		this resolver is not associated with a local key.
	 */
	public PublicKey getPublicKey();

	/**
	 * @return The public key associated with the local entity, or null if
	 * 		this resolver is not associated with a local key.
	 */
	public Certificate getCertificate();

	/**
	 * @return The alias of the local entity's key pair, or null if
	 * 		this resolver is not associated with a local key.
	 */
	public String getKeyAlias();
}
