package intient.xml.keys;

import java.math.BigInteger;
import java.security.PublicKey;

import intient.xml.exception.KeySelectorException;

/** 
 * Selects public key to validate XML signing from some external source. 
 * @author Bradley Beddoes
 */
public interface PublicKeySelector
{
	
	/**
	 * Resolves keys from some external source to validate XML document.
	 * 
	 * @param keyName Name of the key to resolve
	 * @return The public key represented by supplied name
	 * @throws KeySelectorException on internal error or when key not located
	 */
	public PublicKey selectKey(String keyName) throws KeySelectorException;
	
	/**
	 * Resolves keys from some external source to validate XML document.
	 * 
	 * @param issuerName The issuer name of the key to resolve
	 * @param serialNumber The serial number of the key to resolve. This must be unique per issuer DN.
	 * @return The public key associated with the issuerDN and serialNumber
	 * @throws KeySelectorException on internal error or when key not located
	 */
	public PublicKey selectKey(String issuerName, BigInteger serialNumber) throws KeySelectorException;
}
